# Sistem Bilgisi Kontrolü
$windowsVersion = (Get-ItemProperty -Path 'HKLM:\SOFTWARE\Microsoft\Windows NT\CurrentVersion').DisplayVersion
$windowsProductName = systeminfo | findstr /B /C:"OS Name"
$WindowsProduct=""
# Windows 10 veya 11 Kontrolü
if ($windowsProductName -like "*Windows 11*") {
    Write-Host "İşletim sistemi: Windows 11"
} elseif ($windowsProductName -like "*Windows 10*") {
    Write-Host "İşletim sistemi: Windows 10"
} else {
    Write-Host "Bu script sadece Windows 10 ve Windows 11 için geçerlidir."
    exit 1
}


# Güncelleme Bilgileri
$update24H2 = "KB5048667"
$update23H2_22H2 = "KB5048685"
$update_Win10_22H2="KB5048652"


$24H2_update_url = "https://catalog.sf.dl.delivery.mp.microsoft.com/filestreamingservice/files/09ba511a-e6ca-4e90-8e3a-ec4e558f6c98/public/windows11.0-kb5048667-x64_d4ad0ca69de9a02bc356757581e0e0d6960c9f93.msu"
$23H2_22H2_update_url = "https://catalog.sf.dl.delivery.mp.microsoft.com/filestreamingservice/files/d2584a30-89ea-4236-af04-2585566deaa6/public/windows11.0-kb5048685-x64_f1967f623976c41d20deab623317c4855e9d111a.msu"
$Win10_22H2="https://catalog.s.download.windowsupdate.com/d/msdownload/update/software/secu/2024/12/windows10.0-kb5048652-x64_279b3aca56a2aa72aa2d08ccc30fad69bd5a1e29.msu"

$updateToInstall = ""

# Windows sürümüne göre güncelleme belirleme
if ($windowsProductName -like "*Windows 11*") {
    if ($windowsVersion -eq "24H2") {
        Write-Host "Windows sürümü: 24H2"
        $updateToInstall = $update24H2
        $updateUrl = $24H2_update_url
    } elseif ($windowsVersion -eq "23H2") {
        Write-Host "Windows sürümü: 23H2"
        $updateToInstall = $update23H2_22H2
        $updateUrl = $23H2_22H2_update_url
    } elseif ($windowsVersion -eq "22H2") {
        Write-Host "Windows sürümü: 22H2"
        $updateToInstall = $update23H2_22H2
        $updateUrl = $23H2_22H2_update_url
    } else {
        Write-Host "Bu script sadece Windows 11 için 24H2, 23H2 ve 22H2 sürümleri için geçerlidir."
        exit 1
    }
}
elseif($windowsProductName -like "*Windows 10*"){
    if ($windowsVersion -eq "22H2") {
        Write-Host "Windows sürümü: 22H2"
        $updateToInstall = $update_Win10_22H2
        $updateUrl = $Win10_22H2
    }
    else{
        Write-Host "Bu script sadece Windows 10 için 22H2 sürümü için geçerlidir."
    }
}else{
   Write-Host "Bu script sadece Windows 10 için 22H2 sürümü ve Windows 11 için 24H2, 23H2 ve 22H2 sürümleri için geçerlidir." 
}

# Güncelleme Yüklü Mü Kontrolü
$isInstalled = Get-HotFix | Where-Object { $_.HotFixID -eq $updateToInstall }

if ($isInstalled) {
    Write-Host "Güncelleme zaten yüklü: $updateToInstall"
} else {
    Write-Host "Güncelleme yükleniyor: $updateToInstall"
    
    # C:\Temp dizini yoksa oluştur
    if (-not (Test-Path -Path "C:\Temp")) {
        New-Item -Path "C:\Temp" -ItemType Directory
    }

    # Güncelleme dosyasını indirme
    $downloadPath = "C:\Temp\$updateToInstall.msu"
    Invoke-WebRequest -Uri $updateUrl -OutFile $downloadPath

    # Güncellemeyi yükleme
    Start-Process -FilePath "wusa.exe" -ArgumentList "$downloadPath /quiet /norestart" -Wait

    # Yüklemeden sonra doğrulama
    $isInstalled = Get-HotFix | Where-Object { $_.HotFixID -eq $updateToInstall }
    if ($isInstalled) {
        Write-Host "Güncelleme başarıyla yüklendi: $updateToInstall"
    } else {
        Write-Host "Güncelleme yüklenemedi: $updateToInstall"
        exit 1
    }
}